# ⚅⚅⚅ The d666 RPG System ⚅⚅⚅

A rules-light tabletop roleplaying game by Jeremy Deram.

*"Simplicity is the ultimate sophistication."* --Leonardo DaVinci


## Table of Contents
1. [Introduction](rules/book1/01_introduction.md)
2. [Character Creation](rules/book1/02_character_creation.md)
3. [How to Play](rules/book1/03_how_to_play.md)
4. [Magic](rules/book1/04_magic.md)
5. [Monsters](rules/book2/05_monsters.md)
6. [Treasures](rules/book2/06_treasures.md)

#### Appendices
- A. [Converting Classic Monsters](rules/book3/appendix_a_converting_monsters.md)
- B. [Optional Rules](rules/book3/appendix_b_optional_rules.md)

## Online Character Generator
[`https://jderam.github.io/d666-rpg-system/html/chargen.html?level=1&name=auto`](https://jderam.github.io/d666-system/html/chargen.html?level=1&name=auto)

Edit query parameters in the url as follows:
- Update `level` to generate a character of a higher level, e.g. `level=5`
- Update `name` to modify how name is generated
  - `name=auto` will generate a random name
  - Use any other value to populate a specific name of your choice, e.g. `name=Steve`
  - Remove the `name` query parameter to leave name blank, so you can think about it and write one in later. Let's face it, naming is hard.

## License
This game is released under the [CC BY-SA 4.0](https://creativecommons.org/licenses/by-sa/4.0/) license.


⚀ ⚁ ⚂ ⚃ ⚄ ⚅
